@@ -30,7 +30,7 @@ GIT_VERSION=$(git describe | sed 's,-,.,' | env G=$(date +%s) sed "s,-g.*,,")
 while : ; do [[ ${GIT_VERSION} =~ ^[0-9]*\.[0-9]*\.[0-9]*$ ]] && break; GIT_VERSION+=".0"; done
 # 0.10 -> 0.10.0
 LAST_COMMIT_DATE_EMAIL="$(git show | grep ^Date | sed 's,^Date:\s*,,' | awk '{print $1", "$3" "$2" "$5" "$4" "$6}')"
-LAST_COMMIT_DATE_TIME_STAMP=$(date +%Y%m%d.%H%M%S -d "$LAST_COMMIT_DATE_EMAIL")
+LAST_COMMIT_DATE_TIME_STAMP=$(date +%Y%m%d -d "$LAST_COMMIT_DATE_EMAIL")
 UPSTREAM_VERSION=${GIT_VERSION}.${LAST_COMMIT_DATE_TIME_STAMP}
 DFSG_VERSION="${UPSTREAM_VERSION}+dfsg${DFSG}"
 cd ..
